@@ -1,11 +1,11 @@
 """
-A jenkins build represents a single execution of a Jenkins Job.
+A Jenkins build represents a single execution of a Jenkins Job.
 
-Builds can be thought of as the second level of the jenkins heirarchy
+Builds can be thought of as the second level of the Jenkins hierarchy
 beneath Jobs. Builds can have state, such as whether they are running or
-not. They can also have outcomes, such as wether they passed or failed.
+not. They can also have outcomes, such as whether they passed or failed.
 
-Build objects can be associated with Results and Artifacts.g
+Build objects can be associated with Results and Artifacts.
 """
 
 import time
@@ -33,21 +33,22 @@ log = logging.getLogger(__name__)
 class Build(JenkinsBase):
 
     """
-    Represents a jenkins build, executed in context of a job.
+    Represents a Jenkins build, executed in context of a job.
     """
 
     STR_TOTALCOUNT = "totalCount"
-    STR_TPL_NOTESTS_ERR = ("%s has status %s, and does not have "
-                           "any test results")
+    STR_TPL_NOTESTS_ERR = (
+        "%s has status %s, and does not have " "any test results"
+    )
 
     def __init__(self, url, buildno, job, depth=1):
         """
         depth=1 is for backward compatibility consideration
 
         About depth, the deeper it is, the more build data you get back. If
-        depth=0 is sufficient for you, don't go up to 1. See section 'Depth
-        control' of
-        https://wiki.jenkins-ci.org/display/JENKINS/Remote+access+API
+        depth=0 is sufficient for you, don't go up to 1. For more
+        information, see
+        https://www.jenkins.io/doc/book/using/remote-access-api/#RemoteaccessAPI-Depthcontrol
         """
         assert isinstance(buildno, int)
         self.buildno = buildno
@@ -56,14 +57,14 @@ class Build(JenkinsBase):
         JenkinsBase.__init__(self, url)
 
     def _poll(self, tree=None):
-        # For build's we need more information for downstream and
+        # For builds we need more information for downstream and
         # upstream builds so we override the poll to get at the extra
         # data for build objects
         url = self.python_api_url(self.baseurl)
-        return self.get_data(url, params={'depth': self.depth}, tree=tree)
+        return self.get_data(url, params={"depth": self.depth}, tree=tree)
 
     def __str__(self):
-        return self._data['fullDisplayName']
+        return self._data["fullDisplayName"]
 
     @property
     def name(self):
@@ -82,32 +83,36 @@ class Build(JenkinsBase):
         return self._data["builtOn"]
 
     def get_revision(self):
-        return getattr(self, '_get_%s_rev' % self._get_vcs(), lambda: None)()
+        return getattr(self, "_get_%s_rev" % self._get_vcs(), lambda: None)()
 
     def get_revision_branch(self):
-        return getattr(self, '_get_%s_rev_branch' % self._get_vcs(), lambda: None)()
+        return getattr(
+            self, "_get_%s_rev_branch" % self._get_vcs(), lambda: None
+        )()
 
     def get_repo_url(self):
-        return getattr(self, '_get_%s_repo_url' % self._get_vcs(), lambda: None)()
+        return getattr(
+            self, "_get_%s_repo_url" % self._get_vcs(), lambda: None
+        )()
 
     def get_params(self):
         """
-        Return a dictionary of params names and their values or None
-        if no parameters present
+        Return a dictionary of params names and their values, or an
+        empty dictionary if no parameters are returned.
         """
         # This is what a parameter action looks like:
         # {'_class': 'hudson.model.ParametersAction', 'parameters': [
         #     {'_class': 'hudson.model.StringParameterValue',
         #      'value': '12',
         #      'name': 'FOO_BAR_BAZ'}]}
-        actions = self._data.get('actions')
+        actions = self._data.get("actions")
         if actions:
             parameters = {}
             for elem in actions:
-                if elem.get('_class') == 'hudson.model.ParametersAction':
-                    parameters = elem.get('parameters', {})
+                if elem.get("_class") == "hudson.model.ParametersAction":
+                    parameters = elem.get("parameters", {})
                     break
-            return {pair['name']: pair.get('value') for pair in parameters}
+            return {pair["name"]: pair.get("value") for pair in parameters}
 
         return {}
 
@@ -136,12 +141,12 @@ class Build(JenkinsBase):
             "user": "username"
         }
         """
-        if 'changeSet' in self._data:
-            if 'items' in self._data['changeSet']:
-                return self._data['changeSet']['items']
-        elif 'changeSets' in self._data:
-            if 'items' in self._data['changeSets']:
-                return self._data['changeSets']['items']
+        if "changeSet" in self._data:
+            if "items" in self._data["changeSet"]:
+                return self._data["changeSet"]["items"]
+        elif "changeSets" in self._data:
+            if "items" in self._data["changeSets"]:
+                return self._data["changeSets"]["items"]
         return []
 
     def _get_vcs(self):
@@ -149,17 +154,18 @@ class Build(JenkinsBase):
         Returns a string VCS.
         By default, 'git' will be used.
         """
-        vcs = 'git'
-        if 'changeSet' in self._data and 'kind' in self._data['changeSet']:
-            vcs = self._data['changeSet']['kind'] or 'git'
-        elif 'changeSets' in self._data and 'kind' in self._data['changeSets']:
-            vcs = self._data['changeSets']['kind'] or 'git'
+        vcs = "git"
+        if "changeSet" in self._data and "kind" in self._data["changeSet"]:
+            vcs = self._data["changeSet"]["kind"] or "git"
+        elif "changeSets" in self._data and "kind" in self._data["changeSets"]:
+            vcs = self._data["changeSets"]["kind"] or "git"
         return vcs
 
     def _get_svn_rev(self):
         warnings.warn(
             "This untested function may soon be removed from Jenkinsapi "
-            "(get_svn_rev).")
+            "(get_svn_rev)."
+        )
         maxRevision = 0
         for repoPathSet in self._data["changeSet"]["revisions"]:
             maxRevision = max(repoPathSet["revision"], maxRevision)
@@ -168,8 +174,9 @@ class Build(JenkinsBase):
     def _get_git_rev(self):
         # Sometimes we have None as part of actions. Filter those actions
         # which have lastBuiltRevision in them
-        _actions = [x for x in self._data['actions']
-                    if x and "lastBuiltRevision" in x]
+        _actions = [
+            x for x in self._data["actions"] if x and "lastBuiltRevision" in x
+        ]
 
         if _actions:
             return _actions[0]["lastBuiltRevision"]["SHA1"]
@@ -179,60 +186,71 @@ class Build(JenkinsBase):
     def _get_hg_rev(self):
         warnings.warn(
             "This untested function may soon be removed from Jenkinsapi "
-            "(_get_hg_rev).")
-        return [x['mercurialNodeName']
-                for x in self._data['actions'] if 'mercurialNodeName' in x][0]
+            "(_get_hg_rev)."
+        )
+        return [
+            x["mercurialNodeName"]
+            for x in self._data["actions"]
+            if "mercurialNodeName" in x
+        ][0]
 
     def _get_svn_rev_branch(self):
-        raise NotImplementedError('_get_svn_rev_branch is not yet implemented')
+        raise NotImplementedError("_get_svn_rev_branch is not yet implemented")
 
     def _get_git_rev_branch(self):
         # Sometimes we have None as part of actions. Filter those actions
         # which have lastBuiltRevision in them
-        _actions = [x for x in self._data['actions']
-                    if x and "lastBuiltRevision" in x]
+        _actions = [
+            x for x in self._data["actions"] if x and "lastBuiltRevision" in x
+        ]
 
         return _actions[0]["lastBuiltRevision"]["branch"]
 
     def _get_hg_rev_branch(self):
-        raise NotImplementedError('_get_hg_rev_branch is not yet implemented')
+        raise NotImplementedError("_get_hg_rev_branch is not yet implemented")
 
     def _get_git_repo_url(self):
         # Sometimes we have None as part of actions. Filter those actions
         # which have lastBuiltRevision in them
-        _actions = [x for x in self._data['actions']
-                    if x and "lastBuiltRevision" in x]
-        # old Jenkins version have key remoteUrl v/s the new version has a list remoteUrls
+        _actions = [
+            x for x in self._data["actions"] if x and "lastBuiltRevision" in x
+        ]
+        # old Jenkins version have key remoteUrl v/s the new version
+        # has a list remoteUrls
         result = _actions[0].get("remoteUrls", _actions[0].get("remoteUrl"))
         if isinstance(result, list):
-            result = ','.join(result)
+            result = ",".join(result)
         return result
 
     def _get_svn_repo_url(self):
-        raise NotImplementedError('_get_svn_repo_url is not yet implemented')
+        raise NotImplementedError("_get_svn_repo_url is not yet implemented")
 
     def _get_hg_repo_url(self):
-        raise NotImplementedError('_get_hg_repo_url is not yet implemented')
+        raise NotImplementedError("_get_hg_repo_url is not yet implemented")
 
     def get_duration(self):
         return datetime.timedelta(milliseconds=self._data["duration"])
 
     def get_build_url(self):
-        return self._data['url']
+        return self._data["url"]
 
     def get_artifacts(self):
-        data = self.poll(tree='artifacts[relativePath,fileName]')
+        data = self.poll(tree="artifacts[relativePath,fileName]")
         for afinfo in data["artifacts"]:
-            url = "%s/artifact/%s" % (self.baseurl,
-                                      quote(afinfo["relativePath"]))
-            af = Artifact(afinfo["fileName"], url, self,
-                          relative_path=afinfo["relativePath"])
+            url = "%s/artifact/%s" % (
+                self.baseurl,
+                quote(afinfo["relativePath"]),
+            )
+            af = Artifact(
+                afinfo["fileName"],
+                url,
+                self,
+                relative_path=afinfo["relativePath"],
+            )
             yield af
 
     def get_artifact_dict(self):
-        return dict(
-            (af.relative_path, af) for af in self.get_artifacts()
-        )
+        return dict((af.relative_path, af) for af in self.get_artifacts())
 
     def get_upstream_job_name(self):
         """
@@ -240,7 +258,7 @@ class Build(JenkinsBase):
         :return: String or None
         """
         try:
-            return self.get_actions()['causes'][0]['upstreamProject']
+            return self.get_actions()["causes"][0]["upstreamProject"]
         except KeyError:
             return None
 
@@ -259,7 +277,7 @@ class Build(JenkinsBase):
         :return: int or None
         """
         try:
-            return int(self.get_actions()['causes'][0]['upstreamBuild'])
+            return int(self.get_actions()["causes"][0]["upstreamBuild"])
         except KeyError:
             return None
 
@@ -280,7 +298,7 @@ class Build(JenkinsBase):
         :return: String or None
         """
         try:
-            return self.get_actions()['parameters'][0]['value']
+            return self.get_actions()["parameters"][0]["value"]
         except KeyError:
             return None
 
@@ -291,7 +309,8 @@ class Build(JenkinsBase):
         """
         warnings.warn(
             "This untested function may soon be removed from Jenkinsapi "
-            "(get_master_job).")
+            "(get_master_job)."
+        )
         if self.get_master_job_name():
             return self.get_jenkins_obj().get_job(self.get_master_job_name())
 
@@ -304,9 +323,10 @@ class Build(JenkinsBase):
         """
         warnings.warn(
             "This untested function may soon be removed from Jenkinsapi "
-            "(get_master_build_number).")
+            "(get_master_build_number)."
+        )
         try:
-            return int(self.get_actions()['parameters'][1]['value'])
+            return int(self.get_actions()["parameters"][1]["value"])
         except KeyError:
             return None
 
@@ -317,7 +337,8 @@ class Build(JenkinsBase):
         """
         warnings.warn(
             "This untested function may soon be removed from Jenkinsapi "
-            "(get_master_build).")
+            "(get_master_build)."
+        )
         master_job = self.get_master_job()
         if master_job:
             return master_job.get_build(self.get_master_build_number())
@@ -331,12 +352,14 @@ class Build(JenkinsBase):
         """
         warnings.warn(
             "This untested function may soon be removed from Jenkinsapi "
-            "(get_downstream_jobs).")
+            "(get_downstream_jobs)."
+        )
         downstream_jobs = []
         try:
             for job_name in self.get_downstream_job_names():
                 downstream_jobs.append(
-                    self.get_jenkins_obj().get_job(job_name))
+                    self.get_jenkins_obj().get_job(job_name)
+                )
             return downstream_jobs
         except (IndexError, KeyError):
             return []
@@ -351,9 +374,9 @@ class Build(JenkinsBase):
         try:
             fingerprints = self._data["fingerprint"]
             for fingerprint in fingerprints:
-                for job_usage in fingerprint['usage']:
-                    if job_usage['name'] in downstream_job_names:
-                        downstream_names.append(job_usage['name'])
+                for job_usage in fingerprint["usage"]:
+                    if job_usage["name"] in downstream_job_names:
+                        downstream_names.append(job_usage["name"])
             return downstream_names
         except (IndexError, KeyError):
             return []
@@ -368,14 +391,16 @@ class Build(JenkinsBase):
         try:  # pylint: disable=R1702
             fingerprints = self._data["fingerprint"]
             for fingerprint in fingerprints:
-                for job_usage in fingerprint['usage']:
-                    if job_usage['name'] in downstream_job_names:
-                        job = self.get_jenkins_obj().get_job(job_usage['name'])
-                        for job_range in job_usage['ranges']['ranges']:
-                            for build_id in range(job_range['start'],
-                                                  job_range['end']):
+                for job_usage in fingerprint["usage"]:
+                    if job_usage["name"] in downstream_job_names:
+                        job = self.get_jenkins_obj().get_job(job_usage["name"])
+                        for job_range in job_usage["ranges"]["ranges"]:
+                            for build_id in range(
+                                job_range["start"], job_range["end"]
+                            ):
                                 downstream_builds.append(
-                                    job.get_build(build_id))
+                                    job.get_build(build_id)
+                                )
             return downstream_builds
         except (IndexError, KeyError):
             return []
@@ -386,18 +411,18 @@ class Build(JenkinsBase):
         matrix configuration
         :return: Generator of Build
         """
-        if 'runs' in self._data:
-            for rinfo in self._data['runs']:
-                number = rinfo['number']
-                if number == self._data['number']:
-                    yield Build(rinfo['url'], number, self.job)
+        if "runs" in self._data:
+            for rinfo in self._data["runs"]:
+                number = rinfo["number"]
+                if number == self._data["number"]:
+                    yield Build(rinfo["url"], number, self.job)
 
     def is_running(self):
         """
         Return a bool if running.
         """
-        data = self.poll(tree='building')
-        return data.get('building', False)
+        data = self.poll(tree="building")
+        return data.get("building", False)
 
     def block(self):
         while self.is_running():
@@ -408,8 +433,9 @@ class Build(JenkinsBase):
         Return a bool, true if the build was good.
         If the build is still running, return False.
         """
-        return (not self.is_running()) and \
-            self._data["result"] == STATUS_SUCCESS
+        return (not self.is_running()) and self._data[
+            "result"
+        ] == STATUS_SUCCESS
 
     def block_until_complete(self, delay=15):
         assert isinstance(delay, int)
@@ -417,8 +443,9 @@ class Build(JenkinsBase):
         while self.is_running():
             total_wait = delay * count
             log.info(
-                msg="Waited %is for %s #%s to complete" %
-                (total_wait, self.job.name, self.name))
+                msg="Waited %is for %s #%s to complete"
+                % (total_wait, self.job.name, self.name)
+            )
             sleep(delay)
             count += 1
 
@@ -439,13 +466,13 @@ class Build(JenkinsBase):
         result_url = self.get_result_url()
         if self.STR_TOTALCOUNT not in self.get_actions():
             raise NoResults(
-                "%s does not have any published results" %
-                str(self))
+                "%s does not have any published results" % str(self)
+            )
         buildstatus = self.get_status()
         if not self.get_actions()[self.STR_TOTALCOUNT]:
             raise NoResults(
-                self.STR_TPL_NOTESTS_ERR %
-                (str(self), buildstatus))
+                self.STR_TPL_NOTESTS_ERR % (str(self), buildstatus)
+            )
         obj_results = ResultSet(result_url, build=self)
         return obj_results
 
@@ -474,8 +501,8 @@ class Build(JenkinsBase):
         for dct_action in self._data["actions"]:
             if dct_action is None:
                 continue
-            if 'causes' in dct_action and dct_action['causes']:
-                all_causes.extend(dct_action['causes'])
+            if "causes" in dct_action and dct_action["causes"]:
+                all_causes.extend(dct_action["causes"])
         return all_causes
 
     def get_timestamp(self):
@@ -484,7 +511,8 @@ class Build(JenkinsBase):
         """
         # Java timestamps are given in miliseconds since the epoch start!
         naive_timestamp = datetime.datetime(
-            *time.gmtime(self._data['timestamp'] / 1000.0)[:6])
+            *time.gmtime(self._data["timestamp"] / 1000.0)[:6]
+        )
         return pytz.utc.localize(naive_timestamp)
 
     def get_console(self):
@@ -499,9 +527,9 @@ class Build(JenkinsBase):
         if isinstance(content, str):
             return content
         elif isinstance(content, bytes):
-            return content.decode('ISO-8859-1')
+            return content.decode("ISO-8859-1")
         else:
-            raise JenkinsAPIException('Unknown content type for console')
+            raise JenkinsAPIException("Unknown content type for console")
 
     def stream_logs(self, interval=0):
         """
@@ -511,17 +539,21 @@ class Build(JenkinsBase):
         size = 0
         more_data = True
         while more_data:
-            resp = self.job.jenkins.requester.get_url(url, params={'start': size})
+            resp = self.job.jenkins.requester.get_url(
+                url, params={"start": size}
+            )
             content = resp.content
             if content:
                 if isinstance(content, str):
                     yield content
                 elif isinstance(content, bytes):
-                    yield content.decode('ISO-8859-1')
+                    yield content.decode("ISO-8859-1")
                 else:
-                    raise JenkinsAPIException('Unknown content type for console')
-            size = resp.headers['X-Text-Size']
-            more_data = resp.headers.get('X-More-Data')
+                    raise JenkinsAPIException(
+                        "Unknown content type for console"
+                    )
+            size = resp.headers["X-Text-Size"]
+            more_data = resp.headers.get("X-More-Data")
             sleep(interval)
 
     def get_estimated_duration(self):
@@ -546,7 +578,14 @@ class Build(JenkinsBase):
             # on redirect to job page. Call to stop works fine, and
             # we don't need to have job page here.
             self.job.jenkins.requester.post_and_confirm_status(
-                url, data='', valid=[302, 200, 500, ])
+                url,
+                data="",
+                valid=[
+                    302,
+                    200,
+                    500,
+                ],
+            )
             return True
         return False
 
@@ -557,20 +596,21 @@ class Build(JenkinsBase):
         This method is using the Environment Injector plugin:
         https://wiki.jenkins-ci.org/display/JENKINS/EnvInject+Plugin
         """
-        url = self.python_api_url('%s/injectedEnvVars' % self.baseurl)
+        url = self.python_api_url("%s/injectedEnvVars" % self.baseurl)
         try:
-            data = self.get_data(url, params={'depth': self.depth})
+            data = self.get_data(url, params={"depth": self.depth})
         except HTTPError as ex:
-            warnings.warn('Make sure the Environment Injector plugin '
-                          'is installed.')
+            warnings.warn(
+                "Make sure the Environment Injector plugin " "is installed."
+            )
             raise ex
-        return data['envMap']
+        return data["envMap"]
 
     def toggle_keep(self):
         """
         Toggle "keep this build forever" on and off
         """
-        url = '%s/toggleLogKeep' % self.baseurl
+        url = "%s/toggleLogKeep" % self.baseurl
         self.get_jenkins_obj().requester.post_and_confirm_status(url, data={})
         self._data = self._poll()
 
