@@ -8,5 +8,5 @@ def main():
     sys.stdout.write(version)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
