@@ -10,9 +10,12 @@ readonly JENKINS_WAR_URL=$1
 readonly JENKINS_PATH=$2
 readonly WAR_FILENAME=$3
 
-if   [[ $(type -t wget) ]]; then wget -O ${JENKINS_PATH}/${WAR_FILENAME} $JENKINS_WAR_URL
+echo "Downloading $JENKINS_WAR_URL to ${JENKINS_PATH}"
+if   [[ $(type -t wget) ]]; then wget -O ${JENKINS_PATH}/${WAR_FILENAME} -q $JENKINS_WAR_URL
 elif [[ $(type -t curl) ]]; then curl -sSL -o ${JENKINS_PATH}/${WAR_FILENAME} $JENKINS_WAR_URL
 else
     echo "Could not find wget or curl"
     exit 1
 fi
+
+echo "Jenkins downloaded"
