@@ -5,9 +5,10 @@ import string
 
 
 def random_string(length=10):
-    return ''.join(random.choice(string.ascii_lowercase)
-                   for i in range(length))
+    return "".join(
+        random.choice(string.ascii_lowercase) for i in range(length)
+    )
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     print(random_string())
