@@ -1,4 +1,4 @@
-import mock
+import unittest.mock as mock
 
 import pytest
 
@@ -7,18 +7,20 @@ from jenkinsapi.view import View
 from jenkinsapi.job import Job
 from jenkinsapi.custom_exceptions import NotFound
 
-DATA = {'description': 'Important Shizz',
-        'jobs': [
-            {'color': 'blue',
-             'name': 'foo',
-             'url': 'http://halob:8080/job/foo/'},
-            {'color': 'red',
-             'name': 'test_jenkinsapi',
-             'url': 'http://halob:8080/job/test_jenkinsapi/'}
-        ],
-        'name': 'FodFanFo',
-        'property': [],
-        'url': 'http://halob:8080/view/FodFanFo/'}
+DATA = {
+    "description": "Important Shizz",
+    "jobs": [
+        {"color": "blue", "name": "foo", "url": "http://halob:8080/job/foo/"},
+        {
+            "color": "red",
+            "name": "test_jenkinsapi",
+            "url": "http://halob:8080/job/test_jenkinsapi/",
+        },
+    ],
+    "name": "FodFanFo",
+    "property": [],
+    "url": "http://halob:8080/view/FodFanFo/",
+}
 
 JOB_DATA = {
     "actions": [],
@@ -31,13 +33,16 @@ JOB_DATA = {
     "builds": [
         {"number": 3, "url": "http://halob:8080/job/foo/3/"},
         {"number": 2, "url": "http://halob:8080/job/foo/2/"},
-        {"number": 1, "url": "http://halob:8080/job/foo/1/"}
+        {"number": 1, "url": "http://halob:8080/job/foo/1/"},
     ],
     "color": "blue",
     "firstBuild": {"number": 1, "url": "http://halob:8080/job/foo/1/"},
     "healthReport": [
-        {"description": "Build stability: No recent builds failed.",
-         "iconUrl": "health-80plus.png", "score": 100}
+        {
+            "description": "Build stability: No recent builds failed.",
+            "iconUrl": "health-80plus.png",
+            "score": 100,
+        }
     ],
     "inQueue": False,
     "keepDependencies": False,
@@ -45,7 +50,10 @@ JOB_DATA = {
     "lastCompletedBuild": {"number": 3, "url": "http://halob:8080/job/foo/3/"},
     "lastFailedBuild": None,
     "lastStableBuild": {"number": 3, "url": "http://halob:8080/job/foo/3/"},
-    "lastSuccessfulBuild": {"number": 3, "url": "http://halob:8080/job/foo/3/"},
+    "lastSuccessfulBuild": {
+        "number": 3,
+        "url": "http://halob:8080/job/foo/3/",
+    },
     "lastUnstableBuild": None,
     "lastUnsuccessfulBuild": None,
     "nextBuildNumber": 4,
@@ -54,31 +62,28 @@ JOB_DATA = {
     "concurrentBuild": False,
     "downstreamProjects": [],
     "scm": {},
-    "upstreamProjects": []
+    "upstreamProjects": [],
 }
 
 
 @pytest.fixture
 def jenkins():
-    jenkins = mock.MagicMock(auto_spec=True)
+    jenkins = mock.MagicMock(autospec=True)
     jenkins.has_job.return_value = False
     return jenkins
 
 
-@mock.patch.object(Job, '_poll', auto_spec=True)
-@mock.patch.object(View, '_poll', auto_spec=True)
 @pytest.fixture
+@mock.patch.object(Job, "_poll", autospec=True)
+@mock.patch.object(View, "_poll", autospec=True)
 def view(_view_poll, _job_poll, jenkins):
     _view_poll.return_value = DATA
     _job_poll.return_value = JOB_DATA
-    return View('http://localhost:800/view/FodFanFo',
-                'FodFanFo',
-                jenkins)
+    return View("http://localhost:800/view/FodFanFo", "FodFanFo", jenkins)
 
 
 @pytest.fixture
 def jenkins_patch():
-
     class Jenkins:
         def has_job(self, job_name):
             return False
@@ -91,7 +96,6 @@ def jenkins_patch():
 
 @pytest.fixture
 def busy_patch():
-
     class Jenkins:
         def has_job(self, job_name):
             return True
@@ -103,43 +107,42 @@ def busy_patch():
 
 
 class TestView:
-
     def test_returns_name_when_repr_is_called(self, view):
-        assert repr(view) == 'FodFanFo'
+        assert repr(view) == "FodFanFo"
 
     def test_returns_name_when_str_method_called(self, view):
-        assert str(view) == 'FodFanFo'
+        assert str(view) == "FodFanFo"
 
     def test_raises_error_when_is_called(self, view):
         with pytest.raises(AttributeError):
             view.id()
 
     def test_returns_name_when_name_property_is_called(self, view):
-        assert view.name == 'FodFanFo'
+        assert view.name == "FodFanFo"
 
-    @mock.patch.object(JenkinsBase, '_poll')
+    @mock.patch.object(JenkinsBase, "_poll")
     def test_iteritems(self, _poll, view):
         _poll.return_value = JOB_DATA
         for job_name, job_obj in view.iteritems():
             assert isinstance(job_obj, Job)
-            assert job_name in ['foo', 'test_jenkinsapi']
+            assert job_name in ["foo", "test_jenkinsapi"]
 
     def test_returns_dict_of_job_info_when_job_dict_method_called(self, view):
         jobs = view.get_job_dict()
 
         assert jobs == {
-            'foo': 'http://halob:8080/job/foo/',
-            'test_jenkinsapi': 'http://halob:8080/job/test_jenkinsapi/'
+            "foo": "http://halob:8080/job/foo/",
+            "test_jenkinsapi": "http://halob:8080/job/test_jenkinsapi/",
         }
 
     def test_returns_len_when_len_is_called(self, view):
         assert len(view) == 2
 
-    @mock.patch.object(JenkinsBase, '_poll')
+    @mock.patch.object(JenkinsBase, "_poll")
     def test_getitem(self, _poll, view):
         _poll.return_value = JOB_DATA
 
-        assert isinstance(view['foo'], Job)
+        assert isinstance(view["foo"], Job)
 
     def test_sets_delete_to_true_when_deleted(self, view):
         view.delete()
@@ -147,24 +150,25 @@ class TestView:
         assert view.deleted
 
     def test_returns_url_when_get_job_url_is_called(self, view):
-        url = view.get_job_url('foo')
+        url = view.get_job_url("foo")
 
-        assert url == 'http://halob:8080/job/foo/'
+        assert url == "http://halob:8080/job/foo/"
 
     def test_raises_not_found_when_get_job_url_is_invalid(self, view):
         with pytest.raises(NotFound):
-            view.get_job_url('bar')
+            view.get_job_url("bar")
 
-    @mock.patch.object(View, 'get_jenkins_obj')
+    @mock.patch.object(View, "get_jenkins_obj")
     def test_returns_false_when_adding_wrong_job(
-            self, _get_jenkins, view, jenkins_patch):
+        self, _get_jenkins, view, jenkins_patch
+    ):
         _get_jenkins.return_value = jenkins_patch()
-        result = view.add_job('bar')
+        result = view.add_job("bar")
 
         assert result is False
 
     def test_returns_false_when_add_existing_job(self, view):
-        result = view.add_job('foo')
+        result = view.add_job("foo")
 
         assert result is False
 
@@ -180,65 +184,67 @@ class TestView:
 
 
 class TestKeys:
-
     def test_returns_key_when_called(self, view):
         keys = view.keys()
 
-        assert 'foo' in list(keys)
-        assert 'test_jenkinsapi' in list(keys)
+        assert "foo" in list(keys)
+        assert "test_jenkinsapi" in list(keys)
 
 
 class TestAddJob:
-
-    @mock.patch.object(JenkinsBase, '_poll')
+    @mock.patch.object(JenkinsBase, "_poll")
     def test_returns_true_when_no_job_provided(self, _poll, view):
         _poll.return_value = DATA
 
-        result = view.add_job('bar')
+        result = view.add_job("bar")
 
         assert result is True
 
-    @mock.patch.object(JenkinsBase, '_poll')
+    @mock.patch.object(JenkinsBase, "_poll")
     def test_returns_false_when_already_registered(self, _poll, view):
         _poll.return_value = DATA
 
-        result = view.add_job('foo')
+        result = view.add_job("foo")
 
         assert result is False
 
-    @mock.patch.object(View, 'get_jenkins_obj')
-    def test_returns_false_when_jenkins_has_job(self, _get_jenkins, view, jenkins_patch):
+    @mock.patch.object(View, "get_jenkins_obj")
+    def test_returns_false_when_jenkins_has_job(
+        self, _get_jenkins, view, jenkins_patch
+    ):
         _get_jenkins.return_value = jenkins_patch()
 
-        result = view.add_job('Foo')
+        result = view.add_job("Foo")
 
         _get_jenkins.assert_called()
         assert result is False
 
-    @mock.patch.object(View, 'get_jenkins_obj')
-    @mock.patch.object(JenkinsBase, '_poll')
-    def test_returns_true_when_jenkins_has_job(self, _poll, _get_jenkins, view, jenkins):
+    @mock.patch.object(View, "get_jenkins_obj")
+    @mock.patch.object(JenkinsBase, "_poll")
+    def test_returns_true_when_jenkins_has_job(
+        self, _poll, _get_jenkins, view, jenkins
+    ):
         _get_jenkins.return_value = jenkins()
         _poll.return_value = DATA
-        result = view.add_job('Foo')
+        result = view.add_job("Foo")
 
         _get_jenkins.assert_called()
         assert result is True
 
 
 class TestRemove:
-    @mock.patch.object(JenkinsBase, '_poll')
+    @mock.patch.object(JenkinsBase, "_poll")
     def test_returns_true_when_job_has_been_removed(self, _poll, view):
         _poll.return_value = DATA
 
-        result = view.remove_job('foo')
+        result = view.remove_job("foo")
 
         assert result is True
 
-    @mock.patch.object(JenkinsBase, '_poll')
+    @mock.patch.object(JenkinsBase, "_poll")
     def test_returns_false_when_job_does_not_exist(self, _poll, view):
         _poll.return_value = DATA
 
-        result = view.remove_job('Non-existant Foo')
+        result = view.remove_job("Non-existant Foo")
 
         assert result is False
